@@ -75,6 +75,20 @@ def _parse_format(args):
     )
 
 
+def _parse_eomonth(args):
+    date = seq_get(args, 0)
+    month_lag = seq_get(args, 1)
+    unit = DATE_DELTA_INTERVAL.get("month")
+
+    if month_lag is None:
+        return exp.LastDateOfMonth(this=date)
+
+    # Remove month lag argument in parser as its compared with the number of arguments of the resulting class
+    args.remove(month_lag)
+
+    return exp.LastDateOfMonth(this=exp.DateAdd(this=date, expression=month_lag, unit=unit))
+
+
 def generate_date_delta_with_unit_sql(self, e):
     func = "DATEADD" if isinstance(e, exp.DateAdd) else "DATEDIFF"
     return f"{func}({self.format_args(e.text('unit'), e.expression, e.this)})"
@@ -229,39 +243,47 @@ class TSQL(Dialect):
         KEYWORDS = {
             **tokens.Tokenizer.KEYWORDS,
             "BIT": TokenType.BOOLEAN,
-            "REAL": TokenType.FLOAT,
-            "NTEXT": TokenType.TEXT,
-            "SMALLDATETIME": TokenType.DATETIME,
             "DATETIME2": TokenType.DATETIME,
             "DATETIMEOFFSET": TokenType.TIMESTAMPTZ,
-            "TIME": TokenType.TIMESTAMP,
+            "DECLARE": TokenType.COMMAND,
             "IMAGE": TokenType.IMAGE,
             "MONEY": TokenType.MONEY,
-            "SMALLMONEY": TokenType.SMALLMONEY,
-            "ROWVERSION": TokenType.ROWVERSION,
-            "UNIQUEIDENTIFIER": TokenType.UNIQUEIDENTIFIER,
-            "XML": TokenType.XML,
-            "SQL_VARIANT": TokenType.VARIANT,
+            "NTEXT": TokenType.TEXT,
             "NVARCHAR(MAX)": TokenType.TEXT,
-            "VARCHAR(MAX)": TokenType.TEXT,
+            "PRINT": TokenType.COMMAND,
+            "REAL": TokenType.FLOAT,
+            "ROWVERSION": TokenType.ROWVERSION,
+            "SMALLDATETIME": TokenType.DATETIME,
+            "SMALLMONEY": TokenType.SMALLMONEY,
+            "SQL_VARIANT": TokenType.VARIANT,
+            "TIME": TokenType.TIMESTAMP,
             "TOP": TokenType.TOP,
+            "UNIQUEIDENTIFIER": TokenType.UNIQUEIDENTIFIER,
+            "VARCHAR(MAX)": TokenType.TEXT,
+            "XML": TokenType.XML,
         }
 
     class Parser(parser.Parser):
         FUNCTIONS = {
             **parser.Parser.FUNCTIONS,  # type: ignore
-            "CHARINDEX": exp.StrPosition.from_arg_list,
+            "CHARINDEX": lambda args: exp.StrPosition(
+                this=seq_get(args, 1),
+                substr=seq_get(args, 0),
+                position=seq_get(args, 2),
+            ),
             "ISNULL": exp.Coalesce.from_arg_list,
             "DATEADD": parse_date_delta(exp.DateAdd, unit_mapping=DATE_DELTA_INTERVAL),
             "DATEDIFF": parse_date_delta(exp.DateDiff, unit_mapping=DATE_DELTA_INTERVAL),
             "DATENAME": _format_time_lambda(exp.TimeToStr, full_format_mapping=True),
             "DATEPART": _format_time_lambda(exp.TimeToStr),
-            "GETDATE": exp.CurrentDate.from_arg_list,
+            "GETDATE": exp.CurrentTimestamp.from_arg_list,
+            "SYSDATETIME": exp.CurrentTimestamp.from_arg_list,
             "IIF": exp.If.from_arg_list,
             "LEN": exp.Length.from_arg_list,
             "REPLICATE": exp.Repeat.from_arg_list,
             "JSON_VALUE": exp.JSONExtractScalar.from_arg_list,
             "FORMAT": _parse_format,
+            "EOMONTH": _parse_eomonth,
         }
 
         VAR_LENGTH_DATATYPES = {
@@ -271,6 +293,9 @@ class TSQL(Dialect):
             DataType.Type.NCHAR,
         }
 
+        # https://learn.microsoft.com/en-us/azure/synapse-analytics/sql-data-warehouse/sql-data-warehouse-tables-temporary#create-a-temporary-table
+        TABLE_PREFIX_TOKENS = {TokenType.HASH, TokenType.PARAMETER}
+
         def _parse_convert(self, strict):
             to = self._parse_types()
             self._match(TokenType.COMMA)
@@ -323,6 +348,7 @@ class TSQL(Dialect):
             exp.DateAdd: generate_date_delta_with_unit_sql,
             exp.DateDiff: generate_date_delta_with_unit_sql,
             exp.CurrentDate: rename_func("GETDATE"),
+            exp.CurrentTimestamp: rename_func("GETDATE"),
             exp.If: rename_func("IIF"),
             exp.NumberToStr: _format_sql,
             exp.TimeToStr: _format_sql,
